==> gmp-mpfr-sys-1.4.2.crate: gmp-mpfr-sys-1.4.2/src/C.rs <==
#![allow(non_snake_case, non_upper_case_globals)]

//! This module is a place-holder for documentation; do not use it in code.

/// This module is a place-holder for documentation; do not use it in code.
///
/// ---
/// <div><span id="start"></span></div>
#[doc(include = "../doc-c/GMP/index.html")]
pub mod GMP {
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/GMP/Algorithms.html")]
    pub const Algorithms: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/GMP/C_002b_002b-Class-Interface.html")]
    pub const CPP_Class_Interface: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/GMP/Concept-Index.html")]
    pub const Concept_Index: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/GMP/Contributors.html")]
    pub const Contributors: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/GMP/Copying.html")]
    pub const Copying: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/GMP/Custom-Allocation.html")]
    pub const Custom_Allocation: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/GMP/Floating_002dpoint-Functions.html")]
    pub const Floating_point_Functions: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/GMP/Formatted-Input.html")]
    pub const Formatted_Input: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/GMP/Formatted-Output.html")]
    pub const Formatted_Output: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/GMP/Function-Index.html")]
    pub const Function_Index: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/GMP/GMP-Basics.html")]
    pub const GMP_Basics: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/GMP/GNU-Free-Documentation-License.html")]
    pub const GNU_Free_Documentation_License: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/GMP/Installing-GMP.html")]
    pub const Installing_GMP: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/GMP/Integer-Functions.html")]
    pub const Integer_Functions: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/GMP/Internals.html")]
    pub const Internals: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/GMP/Introduction-to-GMP.html")]
    pub const Introduction_to_GMP: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/GMP/Language-Bindings.html")]
    pub const Language_Bindings: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/GMP/Low_002dlevel-Functions.html")]
    pub const Low_level_Functions: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/GMP/Random-Number-Functions.html")]
    pub const Random_Number_Functions: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/GMP/Rational-Number-Functions.html")]
    pub const Rational_Number_Functions: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/GMP/References.html")]
    pub const References: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/GMP/Reporting-Bugs.html")]
    pub const Reporting_Bugs: () = ();
}

/// This module is a place-holder for documentation; do not use it in code.
///
/// ---
/// <div><span id="start"></span></div>
#[doc(include = "../doc-c/MPFR/index.html")]
pub mod MPFR {
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/MPFR/API-Compatibility.html")]
    pub const API_Compatibility: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/MPFR/Concept-Index.html")]
    pub const Concept_Index: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/MPFR/Contributors.html")]
    pub const Contributors: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/MPFR/Copying.html")]
    pub const Copying: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/MPFR/Function-and-Type-Index.html")]
    pub const Function_and_Type_Index: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/MPFR/GNU-Free-Documentation-License.html")]
    pub const GNU_Free_Documentation_License: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/MPFR/Installing-MPFR.html")]
    pub const Installing_MPFR: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/MPFR/Introduction-to-MPFR.html")]
    pub const Introduction_to_MPFR: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/MPFR/MPFR-and-the-IEEE-754-Standard.html")]
    pub const MPFR_and_the_IEEE_754_Standard: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/MPFR/MPFR-Basics.html")]
    pub const MPFR_Basics: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/MPFR/MPFR-Interface.html")]
    pub const MPFR_Interface: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/MPFR/References.html")]
    pub const References: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/MPFR/Reporting-Bugs.html")]
    pub const Reporting_Bugs: () = ();
}

/// This module is a place-holder for documentation; do not use it in code.
///
/// ---
/// <div><span id="start"></span></div>
#[doc(include = "../doc-c/MPC/index.html")]
pub mod MPC {
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/MPC/Complex-Functions.html")]
    pub const Complex_Functions: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/MPC/Concept-Index.html")]
    pub const Concept_Index: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/MPC/Copying.html")]
    pub const Copying: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/MPC/Function-Index.html")]
    pub const Function_Index: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/MPC/GNU-Free-Documentation-License.html")]
    pub const GNU_Free_Documentation_License: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/MPC/GNU-MPC-Basics.html")]
    pub const GNU_MPC_Basics: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/MPC/Installing-GNU-MPC.html")]
    pub const Installing_GNU_MPC: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/MPC/Introduction-to-GNU-MPC.html")]
    pub const Introduction_to_GNU_MPC: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/MPC/References.html")]
    pub const References: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc(include = "../doc-c/MPC/Reporting-Bugs.html")]
    pub const Reporting_Bugs: () = ();
}

==> gmp-mpfr-sys-1.5.0.crate: gmp-mpfr-sys-1.5.0/src/C.rs <==
#![allow(non_snake_case, non_upper_case_globals)]

//! This module is a place-holder for documentation; do not use it in code.

/// This module is a place-holder for documentation; do not use it in code.
///
/// ---
/// <div><span id="start"></span></div>
#[doc = include_str!("../doc-c/GMP/index.html")]
pub mod GMP {
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/GMP/Algorithms.html")]
    pub const Algorithms: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/GMP/C_002b_002b-Class-Interface.html")]
    pub const CPP_Class_Interface: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/GMP/Concept-Index.html")]
    pub const Concept_Index: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/GMP/Contributors.html")]
    pub const Contributors: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/GMP/Copying.html")]
    pub const Copying: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/GMP/Custom-Allocation.html")]
    pub const Custom_Allocation: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/GMP/Floating_002dpoint-Functions.html")]
    pub const Floating_point_Functions: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/GMP/Formatted-Input.html")]
    pub const Formatted_Input: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/GMP/Formatted-Output.html")]
    pub const Formatted_Output: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/GMP/Function-Index.html")]
    pub const Function_Index: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/GMP/GMP-Basics.html")]
    pub const GMP_Basics: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/GMP/GNU-Free-Documentation-License.html")]
    pub const GNU_Free_Documentation_License: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/GMP/Installing-GMP.html")]
    pub const Installing_GMP: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/GMP/Integer-Functions.html")]
    pub const Integer_Functions: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/GMP/Internals.html")]
    pub const Internals: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/GMP/Introduction-to-GMP.html")]
    pub const Introduction_to_GMP: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/GMP/Language-Bindings.html")]
    pub const Language_Bindings: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/GMP/Low_002dlevel-Functions.html")]
    pub const Low_level_Functions: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/GMP/Random-Number-Functions.html")]
    pub const Random_Number_Functions: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/GMP/Rational-Number-Functions.html")]
    pub const Rational_Number_Functions: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/GMP/References.html")]
    pub const References: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/GMP/Reporting-Bugs.html")]
    pub const Reporting_Bugs: () = ();
}

/// This module is a place-holder for documentation; do not use it in code.
///
/// ---
/// <div><span id="start"></span></div>
#[doc = include_str!("../doc-c/MPFR/index.html")]
pub mod MPFR {
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/MPFR/API-Compatibility.html")]
    pub const API_Compatibility: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/MPFR/Concept-Index.html")]
    pub const Concept_Index: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/MPFR/Contributors.html")]
    pub const Contributors: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/MPFR/Copying.html")]
    pub const Copying: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/MPFR/Function-and-Type-Index.html")]
    pub const Function_and_Type_Index: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/MPFR/GNU-Free-Documentation-License.html")]
    pub const GNU_Free_Documentation_License: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/MPFR/Installing-MPFR.html")]
    pub const Installing_MPFR: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/MPFR/Introduction-to-MPFR.html")]
    pub const Introduction_to_MPFR: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/MPFR/MPFR-and-the-IEEE-754-Standard.html")]
    pub const MPFR_and_the_IEEE_754_Standard: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/MPFR/MPFR-Basics.html")]
    pub const MPFR_Basics: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/MPFR/MPFR-Interface.html")]
    pub const MPFR_Interface: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/MPFR/References.html")]
    pub const References: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/MPFR/Reporting-Bugs.html")]
    pub const Reporting_Bugs: () = ();
}

/// This module is a place-holder for documentation; do not use it in code.
///
/// ---
/// <div><span id="start"></span></div>
#[doc = include_str!("../doc-c/MPC/index.html")]
pub mod MPC {
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/MPC/Ball-Arithmetic.html")]
    pub const Ball_Arithmetic: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/MPC/Complex-Functions.html")]
    pub const Complex_Functions: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/MPC/Concept-Index.html")]
    pub const Concept_Index: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/MPC/Copying.html")]
    pub const Copying: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/MPC/Function-Index.html")]
    pub const Function_Index: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/MPC/GNU-Free-Documentation-License.html")]
    pub const GNU_Free_Documentation_License: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/MPC/GNU-MPC-Basics.html")]
    pub const GNU_MPC_Basics: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/MPC/Installing-GNU-MPC.html")]
    pub const Installing_GNU_MPC: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/MPC/Introduction-to-GNU-MPC.html")]
    pub const Introduction_to_GNU_MPC: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/MPC/References.html")]
    pub const References: () = ();
    /// This constant is a place-holder for documentation; do not use it in code.
    ///
    /// ---
    /// <div><span id="start"></span></div>
    #[doc = include_str!("../doc-c/MPC/Reporting-Bugs.html")]
    pub const Reporting_Bugs: () = ();
}
